@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,6 +10,7 @@
 #include <cc/command_interpreter.h>
 #include <config/command_mgr.h>
 #include <dhcp/libdhcp++.h>
+#include <dhcp/tests/iface_mgr_test_config.h>
 #include <dhcpsrv/cfgmgr.h>
 #include <dhcpsrv/lease.h>
 #include <dhcpsrv/lease_mgr_factory.h>
@@ -482,7 +483,8 @@ TEST_F(CtrlChannelDhcpv6SrvTest, libreload) {
     std::string response;
     sendUnixCommand("{ \"command\": \"libreload\" }", response);
     EXPECT_EQ("{ \"result\": 0, "
-              "\"text\": \"Hooks libraries successfully reloaded.\" }"
+              "\"text\": \"Hooks libraries successfully reloaded"
+              " (WARNING: libreload is deprecated).\" }"
               , response);
 
     // Check that the libraries have unloaded and reloaded.  The libraries are
@@ -528,7 +530,8 @@ TEST_F(CtrlChannelDhcpv6SrvTest, libreloadFailMultiThreading) {
     std::string response;
     sendUnixCommand("{ \"command\": \"libreload\" }", response);
     EXPECT_EQ("{ \"result\": 1, "
-              "\"text\": \"Failed to reload hooks libraries.\" }"
+              "\"text\": \"Failed to reload hooks libraries "
+              "(WARNING: libreload is deprecated).\" }"
               , response);
 
     // Check that the libraries have unloaded and failed to reload.  The
@@ -995,7 +998,7 @@ TEST_F(CtrlChannelDhcpv6SrvTest, statusGet) {
 
     std::string response_txt;
 
-    // Send the version-get command
+    // Send the status-get command.
     sendUnixCommand("{ \"command\": \"status-get\" }", response_txt);
     ConstElementPtr response;
     ASSERT_NO_THROW(response = Element::fromJSON(response_txt));
@@ -1091,6 +1094,85 @@ TEST_F(CtrlChannelDhcpv6SrvTest, statusGet) {
     EXPECT_EQ(3, found_queue_stats->size());
 }
 
+// Checks that socket status exists in status-get responses.
+TEST_F(CtrlChannelDhcpv6SrvTest, statusGetSockets) {
+    // Create dummy interfaces to test socket status.
+    isc::dhcp::test::IfaceMgrTestConfig test_config(true);
+
+    // Send the status-get command.
+    createUnixChannelServer();
+    string response_text;
+    sendUnixCommand(R"({ "command": "status-get" })", response_text);
+    ConstElementPtr response;
+    ASSERT_NO_THROW(response = Element::fromJSON(response_text));
+    ASSERT_TRUE(response);
+    ASSERT_EQ(Element::map, response->getType());
+    ConstElementPtr result(response->get("result"));
+    ASSERT_TRUE(result);
+    ASSERT_EQ(Element::integer, result->getType());
+    EXPECT_EQ(0, result->intValue());
+    ConstElementPtr arguments(response->get("arguments"));
+    ASSERT_TRUE(arguments);
+    ASSERT_EQ(Element::map, arguments->getType());
+
+    ConstElementPtr sockets(arguments->get("sockets"));
+    ASSERT_TRUE(sockets);
+    ASSERT_EQ(Element::map, sockets->getType());
+
+    ConstElementPtr status(sockets->get("status"));
+    ASSERT_TRUE(status);
+    ASSERT_EQ(Element::string, status->getType());
+    EXPECT_EQ("ready", status->stringValue());
+
+    ConstElementPtr errors(sockets->get("errors"));
+    ASSERT_FALSE(errors);
+}
+
+// Checks that socket status includes errors in status-get responses.
+TEST_F(CtrlChannelDhcpv6SrvTest, statusGetSocketsErrors) {
+    // Create dummy interfaces to test socket status and add a custom down interface.
+    isc::dhcp::test::IfaceMgrTestConfig test_config(true);
+    test_config.addIface("down_interface", 4);
+    test_config.setIfaceFlags("down_interface", FlagLoopback(false), FlagUp(false),
+                              FlagRunning(true), FlagInactive4(false),
+                              FlagInactive6(false));
+
+    // Send the status-get command.
+    createUnixChannelServer();
+    string response_text;
+    sendUnixCommand(R"({ "command": "status-get" })", response_text);
+    ConstElementPtr response;
+    ASSERT_NO_THROW(response = Element::fromJSON(response_text));
+    ASSERT_TRUE(response);
+    ASSERT_EQ(Element::map, response->getType());
+    ConstElementPtr result(response->get("result"));
+    ASSERT_TRUE(result);
+    ASSERT_EQ(Element::integer, result->getType());
+    EXPECT_EQ(0, result->intValue());
+    ConstElementPtr arguments(response->get("arguments"));
+    ASSERT_TRUE(arguments);
+    ASSERT_EQ(Element::map, arguments->getType());
+
+    ConstElementPtr sockets(arguments->get("sockets"));
+    ASSERT_TRUE(sockets);
+    ASSERT_EQ(Element::map, sockets->getType());
+
+    ConstElementPtr status(sockets->get("status"));
+    ASSERT_TRUE(status);
+    ASSERT_EQ(Element::string, status->getType());
+    EXPECT_EQ("failed", status->stringValue());
+
+    ConstElementPtr errors(sockets->get("errors"));
+    ASSERT_TRUE(errors);
+    ASSERT_EQ(Element::list, errors->getType());
+    ASSERT_EQ(1, errors->size());
+
+    ConstElementPtr error(errors->get(0));
+    ASSERT_TRUE(error);
+    ASSERT_EQ(Element::string, error->getType());
+    ASSERT_EQ("the interface down_interface is down", error->stringValue());
+}
+
 // This test verifies that the DHCP server handles server-tag-get command
 TEST_F(CtrlChannelDhcpv6SrvTest, serverTagGet) {
     createUnixChannelServer();
