@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -837,6 +837,59 @@ private:
     /// @return collection of newly allocated leases
     Lease6Collection allocateUnreservedLeases6(ClientContext6& ctx);
 
+    /// @brief Allocates a normal, in-pool, unreserved lease from the pool.
+    ///
+    /// @note This function is called by allocateUnreservedLeases6 and it tries
+    /// to allocate a lease matching hint prefix length if explicitly required.
+    ///
+    /// @param ctx client context that passes all necessary information. See
+    ///        @ref ClientContext6 for details.
+    /// @param hint_lease the hint lease that is stored in the database. It is
+    ///        updated according to search_hint_lease flag.
+    /// @param search_hint_lease flag which indicates if hint_lease should be
+    ///        retrieved from the lease storage or if it is already retrieved.
+    /// @param hint the hint address that the client provided.
+    /// @param hint_prefix_length The hint prefix length that the client
+    ///        provided. For NAs this value is always 128. For PDs, 0 means that
+    ///        there is no hint and that any pool will suffice. The value 128
+    ///        for PDs is most likely a bug in the code when calling the addHint
+    ///        function with the default value for prefix_len parameter. This
+    ///        value is not a valid delegated prefix length anyway so it is
+    ///        treated the same as when there is no hint provided.
+    /// @param original_subnet the initial subnet selected for this client
+    /// @param network the shared network selected for this client (if any)
+    /// @param total_attempts the total number of attempt to allocate an address
+    ///        for this client. This parameter contains the accumulative value
+    ///        for previous calls and current call of this function for the
+    ///        lease allocation for this client (current IAID).
+    /// @param subnets_with_unavail_leases the number of subnets which have no
+    ///        address available for this client. This parameter contains the
+    ///        accumulative value for previous calls and current call of this
+    ///        function for the lease allocation for this client (current IAID).
+    /// @param subnets_with_unavail_pools the number of pools which have no
+    ///        address available for the client. This parameter contains the
+    ///        accumulative value for previous calls and current call of this
+    ///        function for the lease allocation for this client (current IAID).
+    /// @param [out] callout_status callout returned by the lease6_select
+    /// @param prefix_length_match type which indicates the selection criteria
+    ///        for the pools relative to the provided hint prefix length. It is
+    ///        used for allocating PDs only and it is ignored for any non PD
+    ///        type.
+    ///
+    /// @return a new allocated address or null pointer if none is available
+    Lease6Ptr allocateBestMatch(ClientContext6& ctx,
+                                Lease6Ptr& hint_lease,
+                                bool& search_hint_lease,
+                                const isc::asiolink::IOAddress& hint,
+                                uint8_t hint_prefix_length,
+                                Subnet6Ptr original_subnet,
+                                SharedNetwork6Ptr& network,
+                                uint64_t& total_attempts,
+                                uint64_t& subnets_with_unavail_leases,
+                                uint64_t& subnets_with_unavail_pools,
+                                hooks::CalloutHandle::CalloutNextStep& callout_status,
+                                Allocator::PrefixLenMatchType prefix_length_match);
+
     /// @brief Creates new leases based on reservations.
     ///
     /// This method allocates new leases, based on host reservations.
