@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2019-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -51,6 +51,42 @@ BaseNetworkParser::moveReservationMode(ElementPtr config) {
     config->remove("reservation-mode");
 }
 
+void
+BaseNetworkParser::moveReservationMode(CfgGlobalsPtr config) {
+    if (!config->get(CfgGlobals::RESERVATION_MODE)) {
+        return;
+    }
+    if (config->get(CfgGlobals::RESERVATIONS_GLOBAL) ||
+        config->get(CfgGlobals::RESERVATIONS_IN_SUBNET) ||
+        config->get(CfgGlobals::RESERVATIONS_OUT_OF_POOL)) {
+        isc_throw(DhcpConfigError, "invalid use of both 'reservation-mode'"
+                  " and one of 'reservations-global', 'reservations-in-subnet'"
+                  " or 'reservations-out-of-pool' parameters");
+    }
+    std::string hr_mode = config->get(CfgGlobals::RESERVATION_MODE)->stringValue();
+    if ((hr_mode == "disabled") || (hr_mode == "off")) {
+        config->set(CfgGlobals::RESERVATIONS_GLOBAL, Element::create(false));
+        config->set(CfgGlobals::RESERVATIONS_IN_SUBNET, Element::create(false));
+    } else if (hr_mode == "out-of-pool") {
+        config->set(CfgGlobals::RESERVATIONS_GLOBAL, Element::create(false));
+        config->set(CfgGlobals::RESERVATIONS_IN_SUBNET, Element::create(true));
+        config->set(CfgGlobals::RESERVATIONS_OUT_OF_POOL, Element::create(true));
+    } else if (hr_mode == "global") {
+        config->set(CfgGlobals::RESERVATIONS_GLOBAL, Element::create(true));
+        config->set(CfgGlobals::RESERVATIONS_IN_SUBNET, Element::create(false));
+    } else if (hr_mode == "all") {
+        config->set(CfgGlobals::RESERVATIONS_GLOBAL, Element::create(false));
+        config->set(CfgGlobals::RESERVATIONS_IN_SUBNET, Element::create(true));
+        config->set("reservations-out-of-pool", Element::create(false));
+    } else {
+        isc_throw(DhcpConfigError, "invalid reservation-mode parameter: '"
+                  << hr_mode << "' ("
+                  << config->get(CfgGlobals::RESERVATION_MODE)->getPosition()
+                  << ")");
+    }
+    config->set(CfgGlobals::RESERVATION_MODE, ConstElementPtr());
+}
+
 void
 BaseNetworkParser::parseCommon(const ConstElementPtr& network_data,
                                NetworkPtr& network) {
@@ -231,5 +267,31 @@ BaseNetworkParser::parseDdnsParams(const data::ConstElementPtr& network_data,
     }
 }
 
+void
+BaseNetworkParser::parseAllocatorParams(const data::ConstElementPtr& network_data,
+                                        NetworkPtr& network) {
+    if (network_data->contains("allocator")) {
+        auto allocator_type = getString(network_data, "allocator");
+        if ((allocator_type != "iterative") && (allocator_type != "random")) {
+            // Unsupported allocator type used.
+            isc_throw(DhcpConfigError, "supported allocators are: iterative and random");
+        }
+        network->setAllocatorType(allocator_type);
+    }
+}
+
+void
+BaseNetworkParser::parsePdAllocatorParams(const data::ConstElementPtr& network_data,
+                                          Network6Ptr& network) {
+    if (network_data->contains("pd-allocator")) {
+        auto allocator_type = getString(network_data, "pd-allocator");
+        if ((allocator_type != "iterative") && (allocator_type != "random")) {
+            // Unsupported allocator type used.
+            isc_throw(DhcpConfigError, "supported allocators are: iterative and random");
+        }
+        network->setPdAllocatorType(allocator_type);
+    }
+}
+
 } // end of namespace isc::dhcp
 } // end of namespace isc
