@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2022 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,10 +8,13 @@
 #include <dhcp/iface_mgr.h>
 #include <dhcp/dhcp4.h>
 #include <dhcp/libdhcp++.h>
-#include <dhcpsrv/iterative_allocation_state.h>
 #include <dhcpsrv/cfgmgr.h>
 #include <dhcpsrv/cfg_option.h>
 #include <dhcpsrv/dhcpsrv_log.h>
+#include <dhcpsrv/iterative_allocation_state.h>
+#include <dhcpsrv/iterative_allocator.h>
+#include <dhcpsrv/random_allocation_state.h>
+#include <dhcpsrv/random_allocator.h>
 #include <dhcpsrv/parsers/dhcp_parsers.h>
 #include <dhcpsrv/parsers/host_reservation_parser.h>
 #include <dhcpsrv/parsers/host_reservations_list_parser.h>
@@ -500,10 +503,6 @@ PoolParser::parse(PoolStoragePtr pools,
             pool->requireClientClass((*cclass)->stringValue());
         }
     }
-
-    // Create allocation state for iterative allocator. We're going to
-    // make it configurable.
-    pool->setAllocationState(PoolIterativeAllocationState::create(pool));
 }
 
 boost::shared_ptr<OptionDataListParser>
@@ -662,10 +661,6 @@ SubnetConfigParser::createSubnet(ConstElementPtr params) {
     subnet_->setFetchGlobalsFn([]() -> ConstCfgGlobalsPtr {
         return (CfgMgr::instance().getCurrentCfg()->getConfiguredGlobals());
     });
-
-    // Set allocation state for iterative allocator. We will make it
-    // configurable.
-    subnet_->setAllocationState(SubnetIterativeAllocationState::create(subnet_));
 }
 
 boost::shared_ptr<OptionDataListParser>
@@ -725,6 +720,26 @@ Subnet4ConfigParser::parse(ConstElementPtr subnet) {
         }
     }
 
+    // Parse allocator specification.
+    auto network4 = boost::dynamic_pointer_cast<Network>(sn4ptr);
+    parseAllocatorParams(subnet, network4);
+
+    if (sn4ptr->getAllocatorType() == "random") {
+        sn4ptr->setAllocator(Lease::TYPE_V4,
+                              boost::make_shared<RandomAllocator>
+                              (Lease::TYPE_V4, sn4ptr));
+        sn4ptr->setAllocationState(Lease::TYPE_V4, SubnetAllocationStatePtr());
+
+        for (auto pool : *pools_) {
+            pool->setAllocationState(PoolRandomAllocationState::create(pool));
+        }
+
+    } else {
+        for (auto pool : *pools_) {
+            pool->setAllocationState(PoolIterativeAllocationState::create(pool));
+        }
+    }
+
     return (sn4ptr);
 }
 
@@ -1033,14 +1048,14 @@ Subnets4ListConfigParser::createSubnetConfigParser() const {
 //**************************** Pool6Parser *********************************
 
 PoolPtr
-Pool6Parser::poolMaker (IOAddress &addr, uint32_t len, int32_t ptype)
+Pool6Parser::poolMaker(IOAddress &addr, uint32_t len, int32_t ptype)
 {
     return (PoolPtr(new Pool6(static_cast<isc::dhcp::Lease::Type>
                               (ptype), addr, len)));
 }
 
 PoolPtr
-Pool6Parser::poolMaker (IOAddress &min, IOAddress &max, int32_t ptype)
+Pool6Parser::poolMaker(IOAddress &min, IOAddress &max, int32_t ptype)
 {
     return (PoolPtr(new Pool6(static_cast<isc::dhcp::Lease::Type>
                               (ptype), min, max)));
@@ -1232,13 +1247,67 @@ Subnet6ConfigParser::parse(ConstElementPtr subnet) {
         }
     }
 
+    // Parse allocator specification.
+    auto network = boost::dynamic_pointer_cast<Network>(sn6ptr);
+    parseAllocatorParams(subnet, network);
+
+    // Parse pd-allocator specification.
+    auto network6 = boost::dynamic_pointer_cast<Network6>(sn6ptr);
+    parsePdAllocatorParams(subnet, network6);
+
+    // If we use the random allocator we need to create its instance and
+    // the state instance for it. There is no need to do it for the iterative
+    // allocator because it is configured by default.
+    if (sn6ptr->getAllocatorType() == "random") {
+        sn6ptr->setAllocator(Lease::TYPE_NA,
+                              boost::make_shared<RandomAllocator>
+                              (Lease::TYPE_NA, sn6ptr));
+        sn6ptr->setAllocator(Lease::TYPE_TA,
+                              boost::make_shared<RandomAllocator>
+                              (Lease::TYPE_TA, sn6ptr));
+        sn6ptr->setAllocationState(Lease::TYPE_NA, SubnetAllocationStatePtr());
+        sn6ptr->setAllocationState(Lease::TYPE_TA, SubnetAllocationStatePtr());
+
+    }
+
+    // Repeat the same for the delegated prefix allocator.
+    if (sn6ptr->getPdAllocatorType() == "random") {
+        sn6ptr->setAllocator(Lease::TYPE_PD,
+                              boost::make_shared<RandomAllocator>
+                              (Lease::TYPE_PD, sn6ptr));
+        sn6ptr->setAllocationState(Lease::TYPE_PD, SubnetAllocationStatePtr());
+
+    }
+
+    // Create states for the pools.
+    for (auto pool : *pools_) {
+        switch (pool->getType()) {
+        case Lease::TYPE_V4:
+        case Lease::TYPE_NA:
+        case Lease::TYPE_TA:
+            if (sn6ptr->getAllocatorType() == "random") {
+                pool->setAllocationState(PoolRandomAllocationState::create(pool));
+            } else {
+                pool->setAllocationState(PoolIterativeAllocationState::create(pool));
+            }
+            break;
+        case Lease::TYPE_PD:
+            if (sn6ptr->getPdAllocatorType() == "random") {
+                pool->setAllocationState(PoolRandomAllocationState::create(pool));
+            } else {
+                pool->setAllocationState(PoolIterativeAllocationState::create(pool));
+            }
+            break;
+        }
+    }
+
     return (sn6ptr);
 }
 
 // Unused?
 void
-Subnet6ConfigParser::duplicate_option_warning(uint32_t code,
-                                              asiolink::IOAddress& addr) {
+Subnet6ConfigParser::duplicateOptionWarning(uint32_t code,
+                                            asiolink::IOAddress& addr) {
     LOG_WARN(dhcpsrv_logger, DHCPSRV_CFGMGR_OPTION_DUPLICATE)
         .arg(code).arg(addr.toText());
 }
