@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2022 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,6 +8,7 @@
 
 #include <asiolink/asio_wrapper.h>
 #include <asiolink/interval_timer.h>
+#include <asiolink/io_service_thread_pool.h>
 #include <asiolink/tls_socket.h>
 #include <http/client.h>
 #include <http/http_log.h>
@@ -1680,8 +1681,9 @@ Connection::receiveCallback(const uint64_t transid,
 
         // EAGAIN and EWOULDBLOCK don't indicate an error in this case. All
         // other errors should terminate the transaction.
-        } if ((ec.value() != boost::asio::error::try_again) &&
-              (ec.value() != boost::asio::error::would_block)) {
+        }
+        if ((ec.value() != boost::asio::error::try_again) &&
+            (ec.value() != boost::asio::error::would_block)) {
             terminate(ec);
             return;
 
@@ -1789,8 +1791,8 @@ public:
             thread_io_service_.reset(new IOService());
 
             // Create the thread pool.
-            thread_pool_.reset(new HttpThreadPool(thread_io_service_, thread_pool_size_,
-                                                  defer_thread_start));
+            thread_pool_.reset(new IoServiceThreadPool(thread_io_service_, thread_pool_size_,
+                                                       defer_thread_start));
 
             // Create the connection pool. Note that we use the thread_pool_size
             // as the maximum connections per URL value.
@@ -1942,7 +1944,7 @@ private:
 
     /// @brief Pool of threads used to service connections in multi-threaded
     /// mode.
-    HttpThreadPoolPtr thread_pool_;
+    IoServiceThreadPoolPtr thread_pool_;
 };
 
 HttpClient::HttpClient(IOService& io_service, size_t thread_pool_size,
